@@ -38,6 +38,8 @@ enum EditMode
 	SHIFT_SELECT	/// Shift Mode
 };
 
+#define		TABCONVCHAR		'\t'
+
 class Editor
 {
 protected:
@@ -47,11 +49,11 @@ protected:
 
 	int				_nFirstLine;		/// screen line first position
 	int				_nLastLine;			/// screen line last postion
-	string::size_type 	_nViewCul;		/// view culumn size
-	int					_nViewLine;		/// view line size
+	int			 	_nViewCul;		/// view culumn size
+	int				_nViewLine;		/// view line size
 	
-	int					_nCurLine;		/// current line position
-	string::size_type	_nCurCulumn;	/// current culumn position
+	int				_nCurLine;		/// current line position
+	int				_nCurCulumn;		/// current culumn position
 	
 	bool			_bLineNumView;	/// Line Number View
 	bool			_bInsert; 		/// Insert mode
@@ -106,7 +108,10 @@ public:
 	
 	bool	Save(const string& sFile, ENCODING	Encode, bool bDosMode = false, bool bBackup = false);
 	bool	Save(File* pFile, ENCODING	Encode, bool bDosMode = false, bool bBackup = false);
-
+	
+	string	TabToEdit(const string& sStr, char cTabChar, const int nTabSize);
+	string	EditToTab(const string& sStr, char cTabChar, const int nTabSize);
+	
 	File*	GetFile() 	{ return &_tFile; }
 	string	GetFileName() const { return _sFile; }
 		
