@@ -29,7 +29,7 @@ class EditorClipboard
 	public:
 		EditorClipboard() : _ClipStatus(Edit_ClipNone) {}
 
-		int		Set(vector<wstring>& sSet, EditClip ClipStatus = Edit_ClipNone)
+		void		Set(vector<wstring>& sSet, EditClip ClipStatus = Edit_ClipNone)
 		{
 			_vClip = sSet;
 			_ClipStatus = ClipStatus;
@@ -53,11 +53,6 @@ class EditorClipboard
 class DoInfo
 {
 public:
-	int 				nLine;		/// 라인 위치
-	int 				nCulumn;		/// 컬럼 위치 저장	
-	int					nDelSize;	///	지운다면 사이즈. 0이면 Insert 않는다.
-	vector<wstring>		vData;		/// 데이터 저장
-	
 	DoInfo(int y, int x, vector<wstring> Data, int DelSize = 0):
 		nLine(y), nCulumn(x), vData(Data), nDelSize(DelSize) {}
 
@@ -79,6 +74,12 @@ public:
 	{
 		vData.push_back(sWStr);
 	}
+
+public:
+	int 				nLine;		/// 라인 위치
+	int 				nCulumn;	/// 컬럼 위치 저장	
+	vector<wstring>		vData;		/// 데이터 저장
+	int					nDelSize;	///	지운다면 사이즈. 0이면 Insert 않는다.
 };
 
 };
