@@ -30,12 +30,11 @@ void Configure::Clear()
 bool Configure::Load(const string& sFilename)
 {
 	if (sFilename.size() == 0) return false;
-
+	
 	ifstream in(sFilename.c_str());
 	if (!in) return false;
 
 	Init();
-	
 	_sFilename = sFilename;
 
 	string line, var, val, section, name;
@@ -86,7 +85,7 @@ bool Configure::Save(const string& sFilename)
 {// 바로 그 파일에다 저장한다.
 	string bakfile = _sFilename, srcfile;
 	
-	if (sFilename.size() == 0)
+	if (sFilename.size() == 0 || bakfile == sFilename)
 	{
 		bakfile = bakfile + ".bak";
 		
@@ -100,79 +99,102 @@ bool Configure::Save(const string& sFilename)
 		srcfile = _sFilename;
 	}
 	else
+	{
+		
 		srcfile = sFilename;
+	}
 
 	ifstream in(bakfile.c_str());
 	ofstream out(srcfile.c_str());
-
-	if (!in) return false;
-	if (!out) return false;
-
-	if (!in) {
-		g_Log.Write("file read failure !!! - %s", bakfile.c_str());
-		return false;
-	}
-
+	
 	if (!out) {
 		g_Log.Write("file write failure !!! - %s", srcfile.c_str());
 		return false;
 	}
 
+	SaveParcing();
+
 	// Modified 된 것을 정리
-	MapType::iterator i = _EnvMap.begin(), end = _EnvMap.end();
+	MapType::iterator i = _EnvMap.begin(), end = _EnvMap.end(), j;
 	MapType mod_list, dup_list;
 
-	for(;i!=end;++i)
+	for(i = _EnvMap.begin(); i != end; ++i)
 		if (i->second.modified)
 			mod_list.insert(*i);
 
-	string line, var, val, section = "", name, lower_name;
+	string 	line, var, val, section, name, lower_name;
+	bool	bFirstSection = false;
 
-	while( !getline(in, line).eof() )
+	if ( in )
 	{
-		if (line.empty() || line[0] == '#' || line[0] == '$')
+		while( !getline(in, line).eof() )
 		{
-			out << line << endl;
-			continue;
-		}
-
-		if (line[0] == '[')
-		{
-			section = getbetween(line, '[', ']');
-			out << line << endl;
-			continue;
-		}
-
-		string::size_type p = line.find('=');
-		if (p == string::npos)
-		{
-			out << line << endl;
-			continue;
-		}
-
-		var = chop(line.substr(0, p));
-		val = chop(line.substr(p+1));
-		if (section != "")
-			name = section + "." + var;
-		else
-			name = var;
+			if (line.empty() || line[0] == '#' || line[0] == '$')
+			{
+				out << line << endl;
+				continue;
+			}
+	
+			if (line[0] == '[')
+			{
+				section = getbetween(line, '[', ']');
+				
+				bool 	bSection = false;
+				for(i = _EnvMap.begin(); i != end; ++i)
+					if (i->second.section == section)
+					{
+						bSection = true;
+						break;
+					}
+				
+				if ( bSection )
+					out << line << endl;
+					
+				bFirstSection = true;
+				//else
+				//	out << '#' << line << endl;
+				continue;
+			}
+	
+			string::size_type p = line.find('=');
+			if (p == string::npos)
+			{
+				out << line << endl;
+				continue;
+			}
+	
+			var = chop(line.substr(0, p));
+			val = chop(line.substr(p+1));
+			if (section != "")
+				name = section + "." + var;
+			else
+				name = var;
+				
+			lower_name = Tolower(name);
+			i = mod_list.find(lower_name);
+			j = _EnvMap.find(lower_name);
+	
+			if ( i != mod_list.end() )
+			{
+				if ( !bFirstSection )
+				{
+					out << "[" << i->second.section.c_str() << "]" << endl;
+					bFirstSection = true;
+				}
+				out << i->second.var.c_str() << " = " << i->second.val.c_str() << endl;
+				dup_list.insert(*i);
+				mod_list.erase(i);
+				continue;
+			}
+			else if ((i = dup_list.find(lower_name)) != dup_list.end())
+			{
+				out << '#' << line << endl;
+				continue;
+		 	}
 			
-		lower_name = Tolower(name);
-
-		i = mod_list.find(lower_name);
-
-		if ( i != mod_list.end() )
-		{
-			out << i->second.var.c_str() << " = " << i->second.val.c_str() << endl;
-			dup_list.insert(*i);
-			mod_list.erase(i);
+			if ( j != _EnvMap.end() )
+				out << line << endl;
 		}
-		else if ((i = dup_list.find(lower_name)) != dup_list.end())
-		{
-			out << '#' << line << endl;
-	 	}
-		else
-			out << line << endl;
 	}
 
 	vector<Entry>	vEntry;
@@ -193,26 +215,29 @@ bool Configure::Save(const string& sFilename)
 		if (sSection != tEntry.section)
 		{
 			if (tEntry.section != "")
-				out << "[" << tEntry.section.c_str() << "]" << endl;
+				out << endl << "[" << tEntry.section.c_str() << "]" << endl;
 		}
-
 		sSection = tEntry.section;
 		
 		out << tEntry.var.c_str() << " = " << tEntry.val.c_str() << endl;
+		
+		g_Log.Write( "Section [%s] [%s] [%s]", tEntry.section.c_str(), tEntry.var.c_str(), tEntry.val.c_str());
 	}
 	
-	in.close();
+	if ( in ) in.close();
 	out.close();
+	
+	if (sFilename != bakfile )
+		remove( bakfile.c_str() );
 	return true;
 }
 
-string Configure::GetValue(const string& section, const string& var)
+string Configure::GetValue(const string& section, const string& var, const string& def)
 {
 	MapType::iterator i = _EnvMap.begin(), end = _EnvMap.end();
 	MapType::iterator j;
 	MapType sectionlist;
 	string		name;
-	string		empty;
 	
 	if (section != "")
 	{
@@ -226,7 +251,7 @@ string Configure::GetValue(const string& section, const string& var)
 		if (j == sectionlist.end())
 		{
 			g_Log.Write("not find config var [%s] section [%s] ", var.c_str(), section.c_str());
-			return empty;
+			return def;
 		}
 	}
 	else
@@ -239,7 +264,7 @@ string Configure::GetValue(const string& section, const string& var)
 				if (i->first.substr(i->first.find('.')+1) == Tolower(var))
 					return i->second.val;
 			g_Log.Write("not find config var [%s]", var.c_str());
-			return empty;
+			return def;
 		}
 	}
 
@@ -261,6 +286,8 @@ void Configure::SetValue(	const string& section,
 		v = Tolower(section) + "." + Tolower(var);
 		
 	MapType::iterator i = _EnvMap.find(v);
+		
+	g_Log.Write( "SetValue :: [%s] [%s] [%s]", section.c_str(), var.c_str(), val.c_str());
 
 	if (i == _EnvMap.end())
 		_EnvMap.insert(MapType::value_type(v, Entry (var, val, section, bSave)));
@@ -272,9 +299,12 @@ void Configure::SetValue(	const string& section,
 	}
 }
 
-bool Configure::GetBool( const std::string& section, const std::string &var)
+bool Configure::GetBool( const std::string& section, const std::string &var, bool def)
 {
-	return (Tolower(GetValue(section, var)) == "on");
+	string sValue = GetValue(section, var);
+	if (sValue.size() == 0) 
+		return def;
+	return (Tolower(sValue) == "on");
 }
 
 };
