@@ -52,8 +52,8 @@
 
 using namespace std;
 
-typedef unsigned int 			uint;	///< unsigned int 재정의
-typedef unsigned long long 		ullong;	///< unsigned long long 재정의
+typedef unsigned int 		 		uint;	///< unsigned int 재정의
+typedef long long 			ullong;	///< off_t 재정의
 
 #define		ERROR	-1		///< ERROR 정의
 #define		SUCCESS 0		///< SUCCESS 정의
