@@ -286,11 +286,11 @@ namespace MLSUTIL
 	/// @brief	현재 사용하는 코드로 바꿔준다. US 면 utf-8로 바꾼다.
 	/// @param	sSrc	문자열
 	/// @param	eEncode	리턴 현재 인코드
-	/// @param	nSize	한글 길이 사이즈 (NULL이면 반환않함)
 	/// @return	 바꾼 문자열
 	string	isKorCode(const string& sSrc, ENCODING* eEncode)
 	{
 		string	sCodeConvertStr;
+		string	strData1, strData2;
 		if (eEncode != NULL) *eEncode = US;
 		if (sSrc == "") return "";
 		bool 	bUS = true;
@@ -341,18 +341,28 @@ namespace MLSUTIL
 				if (eEncode != NULL) *eEncode = KO_EUCKR;
 				return sCodeConvertStr;
 			#endif
-			// euckr로 바꿈.
-			sCodeConvertStr = CodeConvert(sSrc, "EUC-KR", "UTF-8");
-			if (sCodeConvertStr == "")
+
+			// EUCKR 로 본다.
+			strData1 = CodeConvert(sSrc, "UTF-8", "EUC-KR"); 			// UTF8 로 바꿔봄.
+			strData2 = CodeConvert(strData1, "EUC-KR", "UTF-8"); 		// EUCKR 로 바꿔봄.
+	
+			if ( strData1 == "" )
 			{
-				// utf8로 바꿔봄
-				sCodeConvertStr = CodeConvert(sSrc, "UTF-8", "EUC-KR");
-				if (sCodeConvertStr == "") return sSrc;
+				// 현재 : UTF8
+				strData1 = CodeConvert(sSrc, "EUC-KR", "UTF-8"); 		// EUCKR 로 바꿔봄.
+				strData2 = CodeConvert(strData1, "UTF-8", "EUC-KR");	// UTF8 로 바꿔봄.
+				
+				if ( strData1 != "" && sSrc == strData2 )
+				{
+					if (eEncode != NULL) *eEncode = KO_UTF8;
+					return strData1;
+				}
+			}
+			else if ( sSrc == strData2 )
+			{
 				if (eEncode != NULL) *eEncode = KO_EUCKR;
-				return sSrc;
+				return sSrc; // UTF8
 			}
-			if (eEncode != NULL) *eEncode = KO_UTF8;
-			return sCodeConvertStr;
 		}
 		else // 나머지는 utf-8로 바꿈.
 		{
@@ -360,19 +370,29 @@ namespace MLSUTIL
 				sCodeConvertStr = sSrc;
 				if (eEncode != NULL) *eEncode = KO_UTF8;
 				return sCodeConvertStr;
-			#endif
-			// utf8 로 바꿈.
-			sCodeConvertStr = CodeConvert(sSrc, "UTF-8", "EUC-KR");
-			if (sCodeConvertStr == "")
+			#endif		 	
+			
+			// 현재 : UTF8
+			strData1 = CodeConvert(sSrc, "EUC-KR", "UTF-8"); 			// EUCKR 로 바꿔봄.
+			strData2 = CodeConvert(strData1, "UTF-8", "EUC-KR"); 		// UTF8 로 바꿔봄.
+	
+			if ( strData1 == "" )
 			{
-				// euckr로 바꿔봄
-				sCodeConvertStr = CodeConvert(sSrc, "EUC-KR", "UTF-8");
-				if (sCodeConvertStr == "") return sSrc;
+				// EUCKR 로 본다.
+				strData1 = CodeConvert(sSrc, "UTF-8", "EUC-KR"); 		// UTF8 로 바꿔봄.
+				strData2 = CodeConvert(strData1, "EUC-KR", "UTF-8"); 	// EUCKR 로 바꿔봄.
+				
+				if ( strData1 != "" && sSrc == strData2 )
+				{
+					if (eEncode != NULL) *eEncode = KO_EUCKR;
+					return strData1;
+				}
+			}
+			else if ( sSrc == strData2 )
+			{
 				if (eEncode != NULL) *eEncode = KO_UTF8;
-				return sSrc;
+				return sSrc; // UTF8
 			}
-			if (eEncode != NULL) *eEncode = KO_EUCKR;
-			return sCodeConvertStr;	
 		}
 		return sSrc;
 	}
