@@ -15,7 +15,7 @@
 #include "define.h"
 #include "exception.h"
 
-namespace MLS
+namespace MLSUTIL
 {
 	class	MlsMutex
 	{
