@@ -103,11 +103,11 @@ namespace	MLSUTIL
 	///	@brief	숫자를 문자로 바꾸어준다.
 	///	@return	문자화 된 숫자
 	string 	toregular(
-		unsigned int number		///< number	문자로 바꿀 숫자
+		ullong number		///< number	문자로 바꿀 숫자
 		)
 	{
-		unsigned int n=1, p=1;
-		string str;	
+		ullong 		n=1, p=1;
+		string 		str;	
 		str.reserve(10);
 				
 		while(number/10 >= p) {p*=10; n+=1;}
@@ -209,6 +209,20 @@ namespace	MLSUTIL
 		return arg;			
 	}
 
+	string itoa(int number)
+	{
+		char buf[20];
+		snprintf(buf, 20, "%d", number);
+		return buf;
+	}
+
+	string ltoa(long number)
+	{
+		char buf[20];
+		snprintf(buf, sizeof(buf), "%l",  number);
+		return buf;
+	}
+
 	struct interval {
 		int first;
 		int last;
@@ -334,21 +348,20 @@ namespace	MLSUTIL
 		#else
 			string 	s = str;
 			if (s.size() == 0 && s.size() > 10000000) return L"";
-			size_t 		nSize;
 			wstring		wstr;
 			
 			wchar_t*	w = new wchar_t[s.size()+1];
 			memset(w, 0, (s.size()+1)*sizeof(wchar_t));
 			
-			if (nSize = mbstowcs(w, s.c_str(), (uint)s.size()) == -1)
+			if (mbstowcs(w, s.c_str(), s.size()) == (size_t)(-1))
 			{
 				g_Log.Write("mbstowcs func err [%s] [%d] [%s]",
 							s.c_str(), errno, strerror(errno));
-				delete w;
+				delete []w;
 				return L"";
 			}
 			wstr = w;
-			delete w;
+			delete []w;
 			return wstr;
 		#endif
 	}
@@ -394,7 +407,7 @@ namespace	MLSUTIL
 		
 			if (wc.size() == 0) return 0;
 		
-			for (int n = 0; n < wc.size(); n++)
+			for (uint n = 0; n < wc.size(); n++)
 			{
 				if (wc[n] >= (wchar_t)0x100)
 				{
@@ -426,7 +439,7 @@ namespace	MLSUTIL
 			wstring wstr = w;
 			if (wstr.size() == 0) return 0;
 			
-			for (int n = 0; n < wstr.size(); n++)
+			for (uint n = 0; n < wstr.size(); n++)
 			{
 				if (wstr[n] >= (wchar_t)0x100)
 				{
@@ -467,7 +480,7 @@ namespace	MLSUTIL
 			char	mbchar[10];
 			int nPos = 0, nLen = 0, nWidth = 0;
 		
-			for (int n = 0; n < wsrc.size(); n++)
+			for (int n = 0; n < (int)wsrc.size(); n++)
 			{
 				if (wsrc[n] >= (wchar_t)0x100)
 				{
