@@ -335,10 +335,10 @@ int Archive::LineFormatRead(vector<string>&	vLineToken, File* pFileInfo, int nFo
 				{
 					#ifdef __FreeBSD__
 					if (vLineToken.size() == 10)
-						pFileInfo->sName = sFilename + " -> " + vLineToken[9];
+						pFileInfo->sLinkName = vLineToken[9];
 					#else
 					if (vLineToken.size() == 8)
-						pFileInfo->sName = sFilename + " -> " + vLineToken[7];
+						pFileInfo->sLinkName = vLineToken[7];
 					#endif
 				}
 			}
@@ -391,7 +391,7 @@ int Archive::LineFormatRead(vector<string>&	vLineToken, File* pFileInfo, int nFo
 				// Link setting
 				if (pFileInfo->sAttr[0] == 'l')
 					if (vLineToken.size() == 11)
-						pFileInfo->sName = sFilename + " -> " + vLineToken[10];
+						pFileInfo->sLinkName = vLineToken[10];
 			}
 			else
 				return ERROR;
@@ -450,7 +450,7 @@ int Archive::LineFormatRead(vector<string>&	vLineToken, File* pFileInfo, int nFo
 				// Link Setting	
 				if (pFileInfo->sAttr[0] == 'l')
 					if (vLineToken.size() == 8)
-						pFileInfo->sName = sFilename + " -> " + vLineToken[7];
+						pFileInfo->sLinkName = vLineToken[7];
 			}
 			else
 			{
