@@ -577,8 +577,8 @@ static int FtpSendCmd(const char *cmd, char expresp, netbuf *nControl)
     sprintf(buf,"%s\r\n",cmd);
     if (net_write(nControl->handle,buf,strlen(buf)) <= 0)
     {
-		perror("write");
-		return 0;
+		//perror("write");
+		return -1;
     }
     return readresp(expresp, nControl);
 }
@@ -590,20 +590,20 @@ static int FtpSendCmd(const char *cmd, char expresp, netbuf *nControl)
  */
 GLOBALDEF int FtpLogin(const char *user, const char *pass, netbuf *nControl)
 {
-    char tempbuf[64];
-
-    if (((strlen(user) + 7) > sizeof(tempbuf)) ||
-        ((strlen(pass) + 7) > sizeof(tempbuf)))
-        return 0;
-    sprintf(tempbuf,"USER %s",user);
-    if (!FtpSendCmd(tempbuf,'3',nControl))
-    {
-	if (nControl->response[0] == '2')
-	    return 1;
-	return 0;
-    }
-    sprintf(tempbuf,"PASS %s",pass);
-    return FtpSendCmd(tempbuf,'2',nControl);
+	char tempbuf[64];
+	
+	if (((strlen(user) + 7) > sizeof(tempbuf)) ||
+		((strlen(pass) + 7) > sizeof(tempbuf)))
+		return 0;
+	sprintf(tempbuf,"USER %s",user);
+	if ( FtpSendCmd(tempbuf,'3',nControl)  <= 0 )
+	{
+		if (nControl->response[0] == '2')
+			return 1;
+		return 0;
+	}
+	sprintf(tempbuf,"PASS %s",pass);
+	return FtpSendCmd(tempbuf,'2',nControl);
 }
 
 /**
@@ -643,7 +643,7 @@ static int FtpOpenPort(netbuf *nControl, netbuf **nData, int mode, int dir)
     {
 		memset(&sin, 0, l);
 		sin.in.sin_family = AF_INET;
-		if (!FtpSendCmd("PASV",'2',nControl))
+		if ( FtpSendCmd("PASV",'2',nControl) <= 0 )
 			return -1;
 		cp = strchr(nControl->response,'(');
 		if (cp == NULL)
@@ -718,7 +718,7 @@ static int FtpOpenPort(netbuf *nControl, netbuf **nData, int mode, int dir)
 			(unsigned char) sin.sa.sa_data[5],
 			(unsigned char) sin.sa.sa_data[0],
 			(unsigned char) sin.sa.sa_data[1]);
-		if (!FtpSendCmd(buf,'2',nControl))
+		if ( FtpSendCmd(buf,'2',nControl) <= 0 )
 		{
 			net_close(sData);
 			return 0;
@@ -842,7 +842,7 @@ GLOBALDEF int FtpAccess(const char *path, int typ, int mode, netbuf *nControl,
 		return 0;
     }
     sprintf(buf, "TYPE %c", mode);
-    if (!FtpSendCmd(buf, '2', nControl))
+    if ( FtpSendCmd(buf, '2', nControl) <= 0 )
 		return 0;
     switch (typ)
     {
@@ -877,7 +877,7 @@ GLOBALDEF int FtpAccess(const char *path, int typ, int mode, netbuf *nControl,
 	}
     if (FtpOpenPort(nControl, nData, mode, dir) == -1)
 		return 0;
-    if (!FtpSendCmd(buf, '1', nControl))
+    if ( FtpSendCmd(buf, '1', nControl) <= 0 )
     {
 		FtpClose(*nData);
 		*nData = NULL;
@@ -1010,7 +1010,7 @@ GLOBALDEF int FtpSite(const char *cmd, netbuf *nControl)
 	if ((strlen(cmd) + 7) > sizeof(buf))
 		return 0;
 	sprintf(buf,"SITE %s",cmd);
-	if (!FtpSendCmd(buf,'2',nControl))
+	if ( FtpSendCmd(buf,'2',nControl) <= 0 )
 		return 0;
 	return 1;
 }
@@ -1029,7 +1029,7 @@ GLOBALDEF int FtpSysType(char *buf, int max, netbuf *nControl)
     int l = max;
     char *b = buf;
     char *s;
-    if (!FtpSendCmd("SYST",'2',nControl))
+    if ( FtpSendCmd("SYST",'2',nControl) <= 0 )
 		return 0;
     s = &nControl->response[4];
     while ((--l) && (*s != ' '))
@@ -1041,7 +1041,7 @@ GLOBALDEF int FtpSysType(char *buf, int max, netbuf *nControl)
 /**
  * FtpMkdir - create a directory at server
  *
- * return 1 if successful, 0 otherwise
+ * return 1 if successful, 0 otherwise, -1 socket error
  */
 GLOBALDEF int FtpMkdir(const char *path, netbuf *nControl)
 {
@@ -1050,15 +1050,13 @@ GLOBALDEF int FtpMkdir(const char *path, netbuf *nControl)
     if ((strlen(path) + 6) > sizeof(buf))
         return 0;
     sprintf(buf,"MKD %s",path);
-    if (!FtpSendCmd(buf,'2', nControl))
-		return 0;
-    return 1;
+    return FtpSendCmd(buf,'2', nControl);
 }
 
 /**
  * FtpChdir - change path at remote
  *
- * return 1 if successful, 0 otherwise
+ * return 1 if successful, 0 otherwise, -1 socket error
  */
 GLOBALDEF int FtpChdir(const char *path, netbuf *nControl)
 {
@@ -1067,9 +1065,8 @@ GLOBALDEF int FtpChdir(const char *path, netbuf *nControl)
     if ((strlen(path) + 6) > sizeof(buf))
         return 0;
     sprintf(buf,"CWD %s",path);
-    if (!FtpSendCmd(buf,'2',nControl))
-		return 0;
-    return 1;
+    
+	return FtpSendCmd(buf,'2',nControl);
 }
 
 /**
@@ -1079,9 +1076,7 @@ GLOBALDEF int FtpChdir(const char *path, netbuf *nControl)
  */
 GLOBALDEF int FtpCDUp(netbuf *nControl)
 {
-    if (!FtpSendCmd("CDUP",'2',nControl))
-		return 0;
-    return 1;
+    return FtpSendCmd("CDUP",'2',nControl);
 }
 
 /**
@@ -1096,9 +1091,7 @@ GLOBALDEF int FtpRmdir(const char *path, netbuf *nControl)
     if ((strlen(path) + 6) > sizeof(buf))
         return 0;
     sprintf(buf,"RMD %s",path);
-    if (!FtpSendCmd(buf,'2',nControl))
-		return 0;
-    return 1;
+    return FtpSendCmd(buf,'2',nControl);
 }
 
 /**
@@ -1111,7 +1104,7 @@ GLOBALDEF int FtpPwd(char *path, int max, netbuf *nControl)
     int l = max;
     char *b = path;
     char *s;
-    if (!FtpSendCmd("PWD",'2',nControl))
+    if ( FtpSendCmd("PWD",'2',nControl) <= 0 )
 		return 0;
     s = strchr(nControl->response, '"');
     if (s == NULL)
@@ -1216,16 +1209,17 @@ GLOBALDEF int FtpDir(const char *outputfile, const char *path, netbuf *nControl)
 GLOBALDEF int FtpSize(const char *path, int *size, char mode, netbuf *nControl)
 {
     char cmd[256];
-    int resp,sz,rv=1;
+    int 	resp,sz,rv=1;
+	int		nRt = 0;
 
     if ((strlen(path) + 7) > sizeof(cmd))
         return 0;
     sprintf(cmd, "TYPE %c", mode);
-    if (!FtpSendCmd(cmd, '2', nControl))
-		return 0;
+    if ( (nRt = FtpSendCmd(cmd, '2', nControl)) <= 0 )
+		return nRt;
     sprintf(cmd,"SIZE %s",path);
-    if (!FtpSendCmd(cmd,'2',nControl))
-		rv = 0;
+    if ( nRt = FtpSendCmd(cmd,'2',nControl) <= 0 )
+		return nRt;
     else
     {
 		if (sscanf(nControl->response, "%d %d", &resp, &sz) == 2)
@@ -1249,7 +1243,7 @@ GLOBALDEF int FtpModDate(const char *path, char *dt, int max, netbuf *nControl)
     if ((strlen(path) + 7) > sizeof(buf))
 		return 0;
     sprintf(buf,"MDTM %s",path);
-    if (!FtpSendCmd(buf,'2',nControl))
+    if ( FtpSendCmd(buf,'2',nControl) <= 0)
 		rv = 0;
     else
 		strncpy(dt, &nControl->response[4], max);
@@ -1286,17 +1280,16 @@ GLOBALDEF int FtpPut(const char *inputfile, const char *path, char mode,
 GLOBALDEF int FtpRename(const char *src, const char *dst, netbuf *nControl)
 {
     char cmd[256];
+	int  nRt = 0;
 
     if (((strlen(src) + 7) > sizeof(cmd)) ||
         ((strlen(dst) + 7) > sizeof(cmd)))
         return 0;
     sprintf(cmd,"RNFR %s",src);
-    if (!FtpSendCmd(cmd,'3',nControl))
-		return 0;
+    if ( nRt = FtpSendCmd(cmd,'3',nControl) <= 0)
+		return nRt;
     sprintf(cmd,"RNTO %s",dst);
-    if (!FtpSendCmd(cmd,'2',nControl))
-		return 0;
-    return 1;
+    return FtpSendCmd(cmd,'2',nControl);
 }
 
 /**
@@ -1311,9 +1304,7 @@ GLOBALDEF int FtpDelete(const char *fnm, netbuf *nControl)
     if ((strlen(fnm) + 7) > sizeof(cmd))
         return 0;
     sprintf(cmd,"DELE %s",fnm);
-    if (!FtpSendCmd(cmd,'2', nControl))
-		return 0;
-    return 1;
+    return FtpSendCmd(cmd,'2', nControl);
 }
 
 /**
@@ -1327,8 +1318,8 @@ GLOBALDEF void FtpQuit(netbuf *nControl)
 		return;
     FtpSendCmd("QUIT",'2',nControl);
     net_close(nControl->handle);
-    free(nControl->buf);
-    free(nControl);
+    if ( nControl->buf ) free(nControl->buf);
+    if ( nControl ) free(nControl);
 }
 
 /**
