@@ -95,7 +95,9 @@ int		FtpReader::LineFormatRead(vector<string>&	vLineToken, File* pFileInfo)
 		// Link Setting	
 		if (pFileInfo->sAttr[0] == 'l')
 			if (vLineToken.size() == 11)
-				pFileInfo->sName = pFileInfo->sName + " -> " + vLineToken[10];
+			{
+				pFileInfo->sLinkName = vLineToken[10];
+			}
 	}
 	else
 		return ERROR;
@@ -185,6 +187,7 @@ bool	FtpReader::Init(const string& sInitFile)
 		return false;
 	}
 	_bConnected = true;
+	_sInitFile = sInitFile;
 	return true;
 }
 
@@ -230,7 +233,7 @@ string FtpReader::GetRealPath(const string& str) const
 			// . home 디렉토리 지정
 			string sTmp1 = sPath.substr(1);
 			string sTmp2;
-			if (sTmp1.find('/') != -1)
+			if (sTmp1.find('/') != string::npos)
 				sTmp2 = sTmp1.substr(sTmp1.find('/')+1);
 			sPath = _sHome + sTmp2;
 		}
@@ -274,22 +277,34 @@ bool	FtpReader::Read(const string &sPath)
 	else
 		sPathReal = GetRealPath(sPath);
 
-	if (FtpChdir(sPathReal.c_str(), _pDefaultFtpNet) == 0)
+	int nRt = 0;
+
+	if ((nRt = FtpChdir(sPathReal.c_str(), _pDefaultFtpNet)) <= 0)
 	{
 		String sMsgStr;
 		sMsgStr.Append("access error - %s", sPathReal.c_str());
 		MsgBox(_("Error"), sMsgStr.c_str());
+		if (FtpGetSocketID( _pDefaultFtpNet ) == 0)
+		{
+			Destroy();
+			Init(_sInitFile);
+		}
 		return false;
 	}
 	
 	string sListFp = "/tmp/" + _sUser + "@" + _sIP;
 	g_Log.Write("Read List File [%s] [%s]", sListFp.c_str(), sPathReal.c_str());
 
-	if (FtpDir(sListFp.c_str(), sPathReal.c_str(), _pDefaultFtpNet) == 0)
+	if ((nRt = FtpDir(sListFp.c_str(), sPathReal.c_str(), _pDefaultFtpNet)) == 0)
 	{
 		String sMsgStr;
 		sMsgStr.Append("access error - %s", sPathReal.c_str());
 		MsgBox(_("Error"), sMsgStr.c_str());
+		if (FtpGetSocketID( _pDefaultFtpNet ) == 0)
+		{
+			Destroy();
+			Init(_sInitFile);
+		}
 		return false;
 	}
 
@@ -403,11 +418,19 @@ bool	FtpReader::Rename(File* pFile, const string& sRename)
 		sRenameName = sRename;
 	
 	sRenameName = _sCurPath + sRenameName;
-	if (FtpRename(pFile->sFullName.c_str(), sRenameName.c_str(), _pDefaultFtpNet) == 0)
+
+	int nRt = 0;
+	if ((nRt = FtpRename(pFile->sFullName.c_str(), sRenameName.c_str(), _pDefaultFtpNet)) == 0)
 	{
 		String sMsg;
-		sMsg.Append("Rename failure !!! - %s", pFile->sName.c_str());
+		sMsg.Append("Rename failure !!! - %s %s", 
+					pFile->sName.c_str(), FtpLastResponse(_pDefaultFtpNet) );
 		MsgBox(	_("Error"), sMsg.c_str());
+		if (FtpGetSocketID( _pDefaultFtpNet ) == 0)
+		{
+			Destroy();
+			Init(_sInitFile);
+		}
 		return false;
 	}
 	return true;
@@ -416,6 +439,8 @@ bool	FtpReader::Rename(File* pFile, const string& sRename)
 bool	FtpReader::Mkdir(const string& sFullPathName)
 {
 	string sMkdirName;
+	int	nRt = 0;
+
 	if (sFullPathName == "")
 	{
 		if (InputBox(_("Make Directory"), sMkdirName) == ERROR)
@@ -425,11 +450,16 @@ bool	FtpReader::Mkdir(const string& sFullPathName)
 		sMkdirName = sFullPathName;
 	
 	sMkdirName = _sCurPath + sMkdirName;
-	if (FtpMkdir(sMkdirName.c_str(), _pDefaultFtpNet) == 0)
+	if (nRt = FtpMkdir(sMkdirName.c_str(), _pDefaultFtpNet) == 0)
 	{
 		String sMsg;
-		sMsg.Append("Mkdir failure !!! - %s", sMkdirName.c_str());
+		sMsg.Append("Mkdir failure !!! - %s %s", sMkdirName.c_str(),  FtpLastResponse(_pDefaultFtpNet));
 		MsgBox(	_("Error"), sMsg.c_str());
+		if (FtpGetSocketID( _pDefaultFtpNet ) == 0)
+		{
+			Destroy();
+			Init(_sInitFile);
+		}
 		return false;
 	}
 	return true;
@@ -443,6 +473,7 @@ bool  FtpReader::View(const File* pFileOriginal, File* pFileChange)
 	string		sSourceName, sTargetName;
 	char		buf[8192];
 	netbuf*		pFtpNet;
+	int			nRt = 0;
 
 	// 파일 이름이 없을경우 continue
 	if (!pFileOriginal) return false;
@@ -453,14 +484,24 @@ bool  FtpReader::View(const File* pFileOriginal, File* pFileChange)
 
 	g_Log.Write("SFtpReader::View [%s] [%s]", sSourceName.c_str(), sTargetName.c_str());
 	
-	if (!FtpAccess(	sSourceName.c_str(), 
+	if (nRt = FtpAccess(	sSourceName.c_str(), 
 					FTPLIB_FILE_READ, 
 					FTPLIB_IMAGE, 
 					_pDefaultFtpNet, 
-					&pFtpNet))
+					&pFtpNet) <= 0)
 	{
-		String sMsg(_("File access error (%s), continue? !!!"), pFileOriginal->sName.c_str());
-		MsgBox(_("Error"), sMsg.c_str());
+		String sMsg(_("File access error (%s) !!!"), pFileOriginal->sName.c_str());
+		if (FtpGetSocketID( _pDefaultFtpNet ) == 0)
+		{
+			sMsg.Append("- %s",  FtpLastResponse(_pDefaultFtpNet));
+			MsgBox(_("Error"), sMsg.c_str());
+			Destroy();
+			Init(_sInitFile);
+		}
+		else
+		{
+			MsgBox(_("Error"), sMsg.c_str());
+		}
 		return false;
 	}
 
@@ -523,7 +564,6 @@ bool  FtpReader::View(const File* pFileOriginal, File* pFileChange)
 	fclose(out);
 	FtpClose(pFtpNet);
 
-halt_sftp_view:
 	tProgress.End();
 	*pFileChange = *pFileOriginal;
 	pFileChange->sFullName = sTargetName;
@@ -600,7 +640,6 @@ bool	FtpReader::Copy(	Selection& tSelection,
 			if (stat(sTargetName.c_str(), &dir_stat) != -1)
 			{
 				tProgress.End();
-				// 이미 디렉토리가 있다면
 				if (YNBox(_("Error"), _("Directory exists, continue?"), false) == false) break;
 				tProgress.Start();
 				continue;
@@ -621,8 +660,17 @@ bool	FtpReader::Copy(	Selection& tSelection,
 						_pDefaultFtpNet, 
 						&pFtpNet))
 		{
-			String sMsg(_("File access error (%s), continue? !!!"), pFile->sName.c_str());
 			tProgress.End();
+			if (FtpGetSocketID( _pDefaultFtpNet ) == 0)
+			{
+				String sMsg("%s",  FtpLastResponse(_pDefaultFtpNet));
+				MsgBox(_("Error"), sMsg.c_str());
+				Destroy();
+				Init(_sInitFile);
+				return false;
+			}
+			
+			String sMsg(_("File access error (%s), continue? !!!"), pFile->sName.c_str());
 			if (YNBox(_("Error"), sMsg.c_str(), false) == false) break;
 			tProgress.Start();
 			continue;
@@ -763,8 +811,15 @@ askagain_ftp_copy:
 		}
 		else
 		{
-			FtpClose(pFtpNet);
 			tProgress.End();
+			if (FtpGetSocketID( _pDefaultFtpNet ) == 0)
+			{
+				String sMsg("%s",  FtpLastResponse(_pDefaultFtpNet));
+				MsgBox(_("Error"), sMsg.c_str());
+				Destroy();
+				Init(_sInitFile);
+				return false;
+			}
 			if (YNBox(_("Error"), _("local file access error, continue?"), false) == false) break;
 			tProgress.Start();
 			continue;
@@ -794,7 +849,7 @@ halt_ftp_copy:
 
 ///	\brief	파일 삭제
 ///	\return	삭제 여부
-bool	FtpReader::Remove(Selection&	tSelection, bool bMsgShow)
+bool	FtpReader::Remove(Selection&	tSelection, bool bMsgShow, bool bIgnore)
 {
 	CommonProgress tProgress(_("Delete"), "");
 
@@ -817,7 +872,7 @@ bool	FtpReader::Remove(Selection&	tSelection, bool bMsgShow)
 	vector<File*>	vFile, vDirs;
 	
 	// 파일 이동
-	for (int t=0; t< vFiles.size(); t++)
+	for (int t=0; t< (int)vFiles.size(); t++)
 	{
 		File*	pFile = vFiles[t];
 		// 파일 이름이 없을경우 continue
@@ -853,9 +908,17 @@ bool	FtpReader::Remove(Selection&	tSelection, bool bMsgShow)
 
 		if (FtpDelete(sTargetName.c_str(), _pDefaultFtpNet) == 0)
 		{
+			tProgress.End();
+			if (FtpGetSocketID( _pDefaultFtpNet ) == 0)
+			{
+				MsgBox(_("Error"),  FtpLastResponse(_pDefaultFtpNet));
+				Destroy();
+				Init(_sInitFile);
+				return false;
+			}
+
 			String	sStr;
 			sStr.Append(_("ftp file remove failure : %s : continue ? "), pFile->sName.c_str());
-			tProgress.End();
 			if (YNBox(_("Error"), sStr.c_str(), false)==true)
 			{
 				tProgress.Start();
@@ -881,10 +944,19 @@ bool	FtpReader::Remove(Selection&	tSelection, bool bMsgShow)
 		g_Log.Write("Dir Remove [%s]", sTargetName.c_str());
 		if (FtpRmdir(sTargetName.c_str(), _pDefaultFtpNet) == 0)
 		{
+			tProgress.End();
+			if (FtpGetSocketID( _pDefaultFtpNet ) == 0)
+			{
+				MsgBox(_("Error"),  FtpLastResponse(_pDefaultFtpNet));
+				Destroy();
+				Init(_sInitFile);
+				return false;
+			}
+
 			String	sStr;
 			sStr.Append(_("ftp dir remove failure %s : continue ?"), 
 					sTargetName.c_str());
-			tProgress.End();
+			
 			if (YNBox(_("Error"), sStr.c_str(), false)==true)
 			{
 				tProgress.Start();
@@ -914,7 +986,7 @@ bool	FtpReader::Paste(Selection& tSelection)
 	string			sCurName, sTargetPathTmp, sTargetPathTmp2;
 	string			sSourceName, sTargetName;
 	vector<File*>	vFiles;
-	struct stat 	src_stat, tar_stat, dir_stat;
+	struct stat 	src_stat;
 
 	char	buf[8192];
 
@@ -959,6 +1031,13 @@ bool	FtpReader::Paste(Selection& tSelection)
 			{
 				// 이미 디렉토리가 있다면
 				tProgress.End();
+				if (FtpGetSocketID( _pDefaultFtpNet ) == 0)
+				{
+					MsgBox(_("Error"),  FtpLastResponse(_pDefaultFtpNet));
+					Destroy();
+					Init(_sInitFile);
+					return false;
+				}
 				if (YNBox(_("Error"), _("Directory exists, continue?"), false) == false) break;
 				tProgress.Start();
 				continue;
@@ -994,8 +1073,6 @@ bool	FtpReader::Paste(Selection& tSelection)
 
 		g_Log.Write("SFtpReader Paste sTargetName 1 [%s] [%s] [%s]", sSourceName.c_str(), sTargetName.c_str(), _sCurPath.c_str());
 		
-		mode_t permission = src_stat.st_mode;
-
 		// 파일 리스트가 디렉토리 라면
 		if (pFile->bDir) continue;
 
@@ -1008,6 +1085,14 @@ bool	FtpReader::Paste(Selection& tSelection)
 		int 	nSize;
 		if (FtpSize(sTargetName.c_str(), &nSize, FTPLIB_IMAGE, _pDefaultFtpNet) == 0) // fail
 		{
+			if (FtpGetSocketID( _pDefaultFtpNet ) == 0)
+			{
+				MsgBox(_("Error"),  FtpLastResponse(_pDefaultFtpNet));
+				Destroy();
+				Init(_sInitFile);
+				return false;
+			}
+
 			if (bSkipAll) continue;
 			else if (bOverwriteAll == false)
 			{// 파일이 있을 경우..
@@ -1041,7 +1126,6 @@ askagain_ftp_paste:
 						
 					case 2: // rename 
 					{
-						struct stat statbuf;
 						string sRename = pFile->sName;
 						
 						while(1)
@@ -1102,6 +1186,14 @@ askagain_ftp_paste:
 							_pDefaultFtpNet, 
 							&pFtpNet))
 			{
+				if (FtpGetSocketID( _pDefaultFtpNet ) == 0)
+				{
+					MsgBox(_("Error"),  FtpLastResponse(_pDefaultFtpNet));
+					Destroy();
+					Init(_sInitFile);
+					return false;
+				}
+
 				String sMsg(_("File access error (%s), continue? !!!"), pFile->sName.c_str());
 				tProgress.End();
 				MsgBox(_("Error"), sMsg.c_str());
@@ -1128,7 +1220,7 @@ askagain_ftp_paste:
 				if (FtpWrite(buf, uLastSize, pFtpNet) != uLastSize)
 				{
 					tProgress.End();
-					if (YNBox(_("Error"), _("file writing failure. continue>"), false)==true)
+					if (YNBox(_("Error"), _("file writing failure. continue?"), false)==true)
 					{
 						FtpClose(pFtpNet);
 						fclose(fp);
@@ -1173,7 +1265,7 @@ void	FtpReader::EncodeChk(vector<File*>& tFileList, bool bEncChk)
 	bool 		bChgEncode = false;
 	if ( tFileList.size() == 0 ) bChgEncode = true;
 
-	for ( int n = 0; n < tFileList.size(); n++ )
+	for ( int n = 0; n < (int)tFileList.size(); n++ )
 	{
 		isKorCode(tFileList[n]->sFullName,	&eEncode);
 		if ( eEncode != US )
