@@ -27,6 +27,8 @@
 #include "libssh2.h"
 #include "libssh2_sftp.h"
 
+#include "mlscfgload.h"
+
 #include "mlslocale.h"
 
 using namespace MLS;
@@ -36,7 +38,6 @@ SFtpReader::SFtpReader()
 {
 	_sReaderName = "sftp";
 	_sInitTypeName = "sftp://";
-	_bFinger = false;
 	
 	_pSession = NULL;
 	_pChannel = NULL;
@@ -45,6 +46,7 @@ SFtpReader::SFtpReader()
 	_pFileAttr = NULL;
 	_bConnected = false;
 	_eEncode = US;
+	_pDefaultFtpNet = NULL;
 }
 
 SFtpReader::~SFtpReader()
@@ -56,12 +58,33 @@ int		SFtpReader::GetIpUserPw(const string& sStr,
 								string& sIP, 
 								string& sUser, 
 								string& sPasswd,
-								string& sDir)
+								string& sDir,
+								string& sKeyPublic,
+								string& sKeyPrivate)
 {
 	string sStrTmpDir = sStr;
 	if (sStrTmpDir != "")
 	{
-		// la9527:1234@kldp.net:20
+		// la9527:1234@kldp.net:20?prikeypath:pubkeypath
+		string::size_type p1 = sStrTmpDir.find("?");
+
+		if (p1 != string::npos)
+		{
+			string sKeyData = sStrTmpDir.substr(p1+1);
+
+			string::size_type p3 = sKeyData.find(":");
+			
+			if (p3 != string::npos)
+			{
+				sKeyPublic = sKeyData.substr(0, p3);
+				sKeyPrivate = sKeyData.substr(p3+1);
+			}
+			else
+				sKeyPrivate = sKeyData;
+
+			sStrTmpDir = sStrTmpDir.substr(0, p1);
+		}
+		
 		string::size_type p2 = sStrTmpDir.find("/");
 		string sStrTmp = sStrTmpDir;
 		
@@ -116,9 +139,8 @@ void	SFtpReader::GetMethods()
     sLang_cs = libssh2_session_methods(pSession, LIBSSH2_METHOD_LANG_CS);
     sLang_sc = libssh2_session_methods(pSession, LIBSSH2_METHOD_LANG_SC);
 
-	/*
 	g_Log.Write("Kex        :: [%s]",  sKex );
-	g_Log.Write("sHostkey   :: [%s]", sHostkey);
+	g_Log.Write("sHostkey   :: [%s]",  sHostkey);
 	g_Log.Write("sCrypt_cs  :: [%s]",  sCrypt_cs );
 	g_Log.Write("sCrypt_sc  :: [%s]",  sCrypt_sc );
 	g_Log.Write("sMac_cs    :: [%s]",  sMac_cs );
@@ -127,7 +149,6 @@ void	SFtpReader::GetMethods()
 	g_Log.Write("sComp_sc   :: [%s]",  sComp_sc );
 	g_Log.Write("sLang_cs   :: [%s]",  sLang_cs );
 	g_Log.Write("sLang_sc   :: [%s]",  sLang_sc );
-	*/
 }
 
 bool	SFtpReader::SetMethod(int nMethod, const string& str)
@@ -143,19 +164,59 @@ bool	SFtpReader::SetMethod(int nMethod, const string& str)
 	return true;
 }
 
+int		SFtpReader::SessionStartup(const string& sIP)
+{
+	Destroy();
+
+	// Ftp Socket 을 이용한다. (프로그램 보수를 쉽게 하기 위한 방법)
+	if (SFtpConnect(sIP.c_str(), (netbuf**)&_pDefaultFtpNet) == 0)
+		throw Exception("sftp connect fail !!! - %s", sIP.c_str());
+	
+	int	nSockNum = FtpGetSocketID( (netbuf*)_pDefaultFtpNet );
+
+	_pSession = (void*)libssh2_session_init();
+
+	// 참조 : http://libssh2.sourceforge.net/doc/#libssh2sessionmethodpref
+	// 
+	string 	sKex = "none", sHostKey = "none", sCrypt_cs = "none", sMac_cs = "none", sComp_cs = "none";
+
+	sKex = g_tCfg.GetValue("SSH", "Method_Kex", 
+						"diffie-hellman-group1-sha1,diffie-hellman-group14-sha1,diffie-hellman-group-exchange-sha1");
+	sHostKey = g_tCfg.GetValue("SSH", "Method_HostKey", 
+						"ssh-dss,ssh-rsa");
+	sCrypt_cs = g_tCfg.GetValue("SSH", "Method_Crypto",
+						"aes256-cbc,aes192-cbc,aes128-cbc,blowfish-cbc,arcfour,cast128-cbc,3des-cbc,none");
+	sMac_cs = g_tCfg.GetValue("SSH", "Method_Mac", 
+						"hmac-sha1,hmac-sha1-96,hmac-md5,hmac-md5-96,hmac-ripemd160,none");
+	sComp_cs = g_tCfg.GetValue("SSH", "Method_Compress", 
+						"zlib,none");
+
+	SetMethod( LIBSSH2_METHOD_KEX, sKex);
+	SetMethod( LIBSSH2_METHOD_HOSTKEY, sHostKey);
+	SetMethod( LIBSSH2_METHOD_CRYPT_CS, sCrypt_cs);
+	SetMethod( LIBSSH2_METHOD_MAC_CS, sMac_cs);
+	SetMethod( LIBSSH2_METHOD_COMP_CS, sComp_cs);
+
+	if ( libssh2_session_startup((LIBSSH2_SESSION*)_pSession, nSockNum))
+	{
+		GetMethods();
+		throw Exception("Failure establishing SSH session.");
+	}
+	return nSockNum;
+}
+
 bool SFtpReader::Init(const string& sInitFile)
 {
-	string 	sIP, sUser, sPasswd, sDir;
+	string 	sIP, sUser, sPasswd, sDir, sPrivateKey, sPublicKey;
+	int		nKeyAuth = 1;
 	
 	// sInitFile : username:passwd@IP
 	// example   : annonymous:123123@name.com
-	g_Log.Write("SFtpReader::Init");
-
 	string sConnectionInfo = sInitFile;
-
+	
 	while(1)
 	{
-		GetIpUserPw(sConnectionInfo, sIP, sUser, sPasswd, sDir);
+		GetIpUserPw(sConnectionInfo, sIP, sUser, sPasswd, sDir, sPublicKey, sPrivateKey);
 		if (sIP == "" && sUser == "" && sPasswd == "")
 		{	
 			if (InputBox(	_("Input sftp connect url (user:passwd@hostname/dir)"),
@@ -164,24 +225,17 @@ bool SFtpReader::Init(const string& sInitFile)
 		else
 			break;
 	}
-	
-	if (sUser == "" && sPasswd == "")
+
+	if ( sUser == "" )
 	{
 		String sMsg;
 		sMsg.Append("Input sftp username - [%s]", sIP.c_str());
 		if (InputBox(sMsg.c_str(), sUser) == ERROR) return false;
-
-		sMsg.clear();
-		sMsg.Append("Input sftp passwd - [%s@%s]", sUser.c_str(), sIP.c_str());
-		if (InputBox(sMsg.c_str(), sPasswd, true) == ERROR) return false;
-	}
-	else if (sPasswd == "")
-	{
-		String sMsg;
-		sMsg.Append("Input sftp passwd - [%s@%s]", sUser.c_str(), sIP.c_str());
-		if (InputBox(sMsg.c_str(), sPasswd, true) == ERROR) return false;
 	}
 
+	g_Log.Write("sInitFile [%s]", sInitFile.c_str());
+	g_Log.Write("sPrivateKey [%s] sPublicKey [%s]", sPrivateKey.c_str(), sPublicKey.c_str());
+	
 	void*	pWait = NULL;
 
 	try
@@ -193,73 +247,85 @@ bool SFtpReader::Init(const string& sInitFile)
 		if (p1 == string::npos)
 			sIP = sIP + ":22"; // 없으면 22포트로 기본 설정.
 		
-		// Ftp Socket 을 이용한다. (프로그램 보수를 쉽게 하기 위한 방법)
-		if (SFtpConnect(sIP.c_str(), (netbuf**)&_pDefaultFtpNet) == 0)
-			throw Exception("sftp connect fail !!! - %s", sIP.c_str());
+		int	nSockNum = SessionStartup(sIP);
 		
-		int	nSockNum = FtpGetSocketID( (netbuf*)_pDefaultFtpNet );
-		_pSession = (void*)libssh2_session_init();
+		bool bFinger = g_tCfg.GetBool("SSH", "FingerView", false);
 
-		// 참조 : http://libssh2.sourceforge.net/doc/#libssh2sessionmethodpref
-		// 
-		SetMethod( LIBSSH2_METHOD_KEX, "diffie-hellman-group1-sha1,diffie-hellman-group14-sha1");
-		//SetMethod( LIBSSH2_METHOD_HOSTKEY, "ssh-dss,");
-		//SetMethod( LIBSSH2_METHOD_CRYPT_CS, "diffie-hellman-group1-sha1,diffie-hellman-group14-sha1");
-		//SetMethod( LIBSSH2_METHOD_MAC_CS, "diffie-hellman-group1-sha1,diffie-hellman-group14-sha1");
-		//SetMethod( LIBSSH2_METHOD_LANG_CS, "diffie-hellman-group1-sha1,diffie-hellman-group14-sha1");
-
-		int	nRt = 0;
-		if ( nRt = libssh2_session_startup((LIBSSH2_SESSION*)_pSession, nSockNum))
-		{
-			GetMethods();
-			throw Exception("Failure establishing SSH session [%s@%s]", sUser.c_str(), sIP.c_str());
-		}
-
-		if (_bFinger)
+		if ( bFinger )
 		{
 			const char *fingerprint = libssh2_hostkey_hash((LIBSSH2_SESSION*)_pSession, LIBSSH2_HOSTKEY_HASH_MD5);	
 			if ( fingerprint )
 			{
 				String	strMsg;
 				for(int i = 0; i < 16; i++) {
-					strMsg.Append("%02X:", (unsigned char)fingerprint[i]);
-				}		
+					strMsg.Append("%02X", (unsigned char)fingerprint[i]);
+					if (i < 15 ) 
+						strMsg.Append(":");
+				}
+				
 				MsgBox(_("RSA key Finger info"), strMsg.c_str());
 			}
 		}
-		
-		if ( sPasswd.size() ) 
+
+		// key or password authentication check.
+		if ( !sPasswd.size() && nKeyAuth == 1)
 		{
-			/* We could authenticate via password */
-			int nRt = libssh2_userauth_password(	(LIBSSH2_SESSION*)_pSession, 
-													sUser.c_str(), sPasswd.c_str());
-			if (nRt == -1) 
+			if (sPrivateKey.size() == 0 || sPublicKey.size() == 0)
 			{
-				int 	n = 0;
-				char*	sStr = NULL;
-				String str("Authentication by password failed.");
-				if (libssh2_session_last_error( (LIBSSH2_SESSION*)_pSession, &sStr, &n, 1024) != 0)
-				{
-					str.Append(" [%s]", sStr);
-					free(sStr);
-				}
-				throw Exception(str.c_str());
+				sPrivateKey = g_tCfg.GetValue("SSH", "DefPrivateKey", "~/.ssh/id_rsa");
+				sPublicKey = g_tCfg.GetValue("SSH", "DefPublicKey", "~/.ssh/id_rsa.pub");
 			}
-		} 
-		else 
-		{
-			string	sCurUserName;
-			string	sPublicKey = "/home/username/.ssh/id_rsa.pub";
-			string	sPrivateKey = "/home/username/.ssh/id_rsa";
+			
+			if (sPrivateKey.substr(0, 1) == "~")
+				sPrivateKey = g_tCfg.GetValue("Static", "Home") + sPrivateKey.substr(1);
+	
+			if (sPublicKey.substr(0, 1) == "~")
+				sPublicKey = g_tCfg.GetValue("Static", "Home") + sPublicKey.substr(1);
+
+			g_Log.Write("%s :: %s :: %s ::", sPrivateKey.c_str(), sPublicKey.c_str(), sUser.c_str());
 	
 			/* Or by public key */
 			if (libssh2_userauth_publickey_fromfile(	(LIBSSH2_SESSION*)_pSession, 
-													sUser.c_str(), 
-													sPublicKey.c_str(), 
-													sPrivateKey.c_str(), 
-													"pasphrase"))
+														sUser.c_str(), 
+														sPublicKey.c_str(), 
+														sPrivateKey.c_str(), 
+														"pasphrase") == 0)
 			{
-				throw Exception("Authentication by public key failed.");
+				nKeyAuth = 2;
+				g_Log.Write("libssh2_userauth_publickey_fromfile SUCCESS");
+			}
+			else
+				nSockNum = SessionStartup(sIP);
+		}
+
+		if ( sPasswd.size() || nKeyAuth != 2)
+		{
+			MsgWaitEnd(pWait);
+
+			if (sPasswd.size() == 0)
+			{
+				String sMsg;
+				sMsg.Append("Input sftp passwd - [%s@%s]", sUser.c_str(), sIP.c_str());
+				if (InputBox(sMsg.c_str(), sPasswd, true) == ERROR) return false;	
+			}
+
+			pWait = MsgWaitBox(_("SFtp connect"), _("Please wait !!!"));
+
+			/* We could authenticate via password */
+			int nRt = libssh2_userauth_password(	(LIBSSH2_SESSION*)_pSession, 
+													sUser.c_str(), sPasswd.c_str());
+			if (nRt == -1)
+			{
+				int 	n = 0;
+				char*	sStr = NULL;
+				String 	str("Authentication by password failed.");
+				if (libssh2_session_last_error( (LIBSSH2_SESSION*)_pSession, &sStr, &n, 1024) != 0)
+				{
+					str.Append("[%s]", sStr);
+					free(sStr);
+				}
+				
+				throw Exception(str.c_str());
 			}
 		}
 
@@ -286,9 +352,6 @@ bool SFtpReader::Init(const string& sInitFile)
 		//	libssh2_channel_set_blocking( (LIBSSH2_CHANNEL*)_pChannel, 1 );
 		//}
 		
-		//if (!(_pSesstionSFtp = (void*)libssh2_sftp_init( (LIBSSH2_SESSION*)_pSession )))
-		//	throw Exception( "Unable to open a sftp session." );
-
 		_pSessionSFtp=(void*)libssh2_sftp_init( (LIBSSH2_SESSION*)_pSession );
 			
 		if (_pSessionSFtp == NULL)
@@ -300,7 +363,9 @@ bool SFtpReader::Init(const string& sInitFile)
 		if (sDir.size() == 0) 
 			sPath = GetPwd();
 		else
+		{
 			sPath = GetRealPath( sDir );
+		}
 
 		if (sPath == "")
 		{
@@ -316,12 +381,13 @@ bool SFtpReader::Init(const string& sInitFile)
 		_sUser = sUser;
 
 		if (!_pFileAttr) 
-			_pFileAttr = (void*)new LIBSSH2_SFTP_ATTRIBUTES;	
-		
+			_pFileAttr = (void*)new LIBSSH2_SFTP_ATTRIBUTES;
+
 		g_Log.Write("SFtp Connected [%s] [%s]", _sInitTypeName.c_str(), _sCurPath.c_str());
 
 		_bConnected = true;
 		_eEncode = US;
+		_sInitFile = sInitFile;
 	}
 	catch (Exception& ex)
 	{
@@ -342,18 +408,6 @@ bool SFtpReader::Init(const string& sInitFile)
 
 void	SFtpReader::Destroy()
 {
-	/*
-	string sDeleteFile;
-
-	for (int n = 0; n < _vDeleteFile.size(); n++)
-	{
-		sDeleteFile = _vDeleteFile[n];
-		sDeleteFile = "rm -rf /tmp/" + addslash(sDeleteFile) + " > /dev/null 2> /dev/null";
-		system(sDeleteFile.c_str());
-	}
-	_vDeleteFile.clear();
-	*/
-
 	if ( _pFileAttr )
 	{
 		delete (LIBSSH2_SFTP_ATTRIBUTES*)_pFileAttr;
@@ -437,6 +491,7 @@ string SFtpReader::GetRealPath(const string& str) const
 			sPath = _sCurPath + sPath;
 		}
 	}
+
 	if (sPath.substr(sPath.size()-1, 1) != "/") sPath += '/';
 	return sPath;
 }
@@ -521,7 +576,10 @@ bool	SFtpReader::GetInfo(File &tFile)
 					if (libssh2_sftp_lstat((LIBSSH2_SFTP*)_pSessionSFtp, cLinkPath, pFileAttr) == -1)
 						tFile.sName = _sTmpFileName;
 					else
-						tFile.sName = _sTmpFileName + " -> " + cLinkPath;
+					{
+						tFile.sLinkName = cLinkPath;
+						tFile.sName = _sTmpFileName;
+					}
 				}
 				else
 				{
@@ -529,7 +587,10 @@ bool	SFtpReader::GetInfo(File &tFile)
 					if (libssh2_sftp_lstat((LIBSSH2_SFTP*)_pSessionSFtp, (char*)sLinkPath.c_str(), pFileAttr) == -1)
 						tFile.sName = _sTmpFileName;
 					else
-						tFile.sName = _sTmpFileName + " -> " + cLinkPath;
+					{
+						tFile.sLinkName = cLinkPath;
+						tFile.sName = _sTmpFileName;
+					}
 				}
 				bLink = true;	
 			}
@@ -675,14 +736,21 @@ bool	SFtpReader::Read(const string& sDir)
 	}
 	catch(Exception& ex)
 	{
-		int 	n = 0;
+		int 	n = 0, nRt = 0;
 		char*	sStr = NULL;
 		String	sMsg;
-		libssh2_session_last_error( (LIBSSH2_SESSION*)_pSession, &sStr, &n, 1024);
+		nRt = libssh2_session_last_error( (LIBSSH2_SESSION*)_pSession, &sStr, &n, 1024);
 		sMsg.Append("%s", (char*)ex);
 		if ( sStr ) { sMsg.Append(" [%s]", sStr); free( sStr ); }
 		MsgBox(_("Error"), sMsg.c_str());
 		//cout << sMsg.c_str() << endl;
+		if (nRt == LIBSSH2_ERROR_SOCKET_TIMEOUT)
+		{
+			string sTmp = _sCurPath;
+			Destroy();
+			Init(_sInitFile);
+			_sCurPath = sTmp;
+		}
 		return false;
 	}
 	return true;
@@ -696,13 +764,6 @@ bool	SFtpReader::Rename(File* pFile, const string& sRename)
 		return false;
 	}
 
-	#ifndef _DEBUG
-	/*
-		MsgBox(_("Error"), _("sftp renmae failer. next version fix.") ); 
-		return false;
-	*/
-	#endif
-
 	string sRenameName = pFile->sName;
 	if (sRenameName == "..") return false;
 
@@ -727,13 +788,20 @@ bool	SFtpReader::Rename(File* pFile, const string& sRename)
 								LIBSSH2_SFTP_RENAME_ATOMIC |
 								LIBSSH2_SFTP_RENAME_NATIVE) == -1)
 	{
-		int 	n = 0;
+		int 	n = 0, nRt = 0;
 		char*	sStr = NULL;
 		String	sMsg;
-		libssh2_session_last_error( (LIBSSH2_SESSION*)_pSession, &sStr, &n, 1024);
+		nRt = libssh2_session_last_error( (LIBSSH2_SESSION*)_pSession, &sStr, &n, 1024);
 		sMsg.Append("SFtp rename failure !!! [%s]", sRename.c_str());
 		if ( sStr ) { sMsg.Append(" [%s]", sStr); free( sStr ); }
 		MsgBox(_("Error"), sMsg.c_str());
+		if (nRt == LIBSSH2_ERROR_SOCKET_TIMEOUT)
+		{
+			string sTmp = _sCurPath;
+			Destroy();
+			Init(_sInitFile);
+			_sCurPath = sTmp;
+		}
 		return false;
 	}
 	return true;
@@ -754,13 +822,20 @@ bool	SFtpReader::Mkdir(const string& sFullPathName)
 
 	if ( libssh2_sftp_mkdir( (LIBSSH2_SFTP*)_pSessionSFtp, (char*)sMkdirName.c_str(), 0755) == -1)
 	{
-		int 	n = 0;
+		int 	n = 0, nRt = 0;
 		char*	sStr = NULL;
 		String	sMsg;
-		libssh2_session_last_error( (LIBSSH2_SESSION*)_pSession, &sStr, &n, 1024);
+		nRt = libssh2_session_last_error( (LIBSSH2_SESSION*)_pSession, &sStr, &n, 1024);
 		sMsg.Append("SFtp mkdir failure !!! [%s]", sFullPathName.c_str());
 		if ( sStr ) { sMsg.Append(" [%s]", sStr); free( sStr ); }
 		MsgBox(_("Error"), sMsg.c_str());
+		if (nRt == LIBSSH2_ERROR_SOCKET_TIMEOUT)
+		{
+			string sTmp = _sCurPath;
+			Destroy();
+			Init(_sInitFile);
+			_sCurPath = sTmp;
+		}
 		return false;
 	}
 	return true;
@@ -783,9 +858,11 @@ bool SFtpReader::Copy(	Selection& tSelection, 		// remote
 	bool	bSkipAll = false, bOverwriteAll = false;
 	ullong	uLastSize = 0, uViewCount=1, uPsize=0, uCsize = 0;
 	
-	struct stat src_stat, tar_stat, dir_stat;
+	struct stat src_stat, tar_stat;
 
-	char	buf[8192];	// reading byte 
+	int	nBufSize = g_tCfg.GetValueNum("SSH", "DefBufSize", 65536);
+
+	char	buf[nBufSize];	// reading byte 
 
 	vFiles = tSelection.GetData();
 
@@ -809,9 +886,10 @@ bool SFtpReader::Copy(	Selection& tSelection, 		// remote
 	g_Log.Write("Copy sTargetPath [%s] [%s] [%s]", sTargetPath.c_str(), _sCurPath.c_str(), sTargetPathTmp2.c_str());
 
 	// 파일 복사
-	for (int n=0; n<vFiles.size(); n++)
+	for (int n=0; n<(int)vFiles.size(); n++)
 	{
 		File*	pFile = vFiles[n];
+		bool	bOverwrite = false;
 		
 		// 파일 이름이 없을경우 continue
 		if (!pFile) continue;
@@ -820,34 +898,6 @@ bool SFtpReader::Copy(	Selection& tSelection, 		// remote
 		sSourceName = pFile->sFullName;
 		sTargetName = sTargetPathTmp2 + pFile->sFullName.substr(sSourcePath.size());
 
-		// 파일 리스트가 디렉토리 라면
-		if (pFile->bDir)
-		{
-			if (pSelection != NULL)
-			{
-				File	tTargetFile = *pFile;
-				tTargetFile.sFullName = sTargetName;
-				pSelection->Add(&tTargetFile);
-			}
-
-			if (stat(sTargetName.c_str(), &dir_stat) != -1)
-			{
-				// 이미 디렉토리가 있다면
-				tProgress.End();
-				if (YNBox(_("Error"), _("Directory exists, continue ?"), false) == false) break;
-				tProgress.Start();
-				continue;
-			}
-			else if (mkdir(sTargetName.c_str(), 0755)==-1) // 디렉토리를 만든다.
-			{// 실패하면
-				tProgress.End();
-				MsgBox(_("Error"), _("Directory Making error"));
-				tProgress.Start();
-				break;
-			}
-			continue;
-		}
-
 		LIBSSH2_SFTP_ATTRIBUTES 	tAttr;
 		if (libssh2_sftp_stat((LIBSSH2_SFTP*)_pSessionSFtp, (char*)sSourceName.c_str(), &tAttr) == -1)
 		{
@@ -896,6 +946,7 @@ askagain_sftp_copy:
 				{
 					case 0:	// overwrite
 						g_Log.Write("OverWrite");
+						bOverwrite = true;
 						break;
 					
 					case 1: // skip
@@ -948,6 +999,29 @@ askagain_sftp_copy:
 			}
 		}
 		
+		// 파일 리스트가 디렉토리 라면
+		if (pFile->bDir)
+		{
+			if (pSelection != NULL)
+			{
+				File	tTargetFile = *pFile;
+				tTargetFile.sFullName = sTargetName;
+				pSelection->Add(&tTargetFile);
+			}
+
+			if (mkdir(sTargetName.c_str(), tAttr.permissions)==-1) // 디렉토리를 만든다.
+			{
+				// 실패하면
+				if ( !bOverwriteAll && !bSkipAll && !bOverwrite)
+				{
+					tProgress.End();
+					MsgBox(_("Error"), _("Directory Making error"));
+					break;
+				}
+			}
+			continue;
+		}
+		
 		uCsize=0;
 		// 실제 복사 오퍼레이션	
 		
@@ -989,7 +1063,7 @@ askagain_sftp_copy:
 					tProgress.Start();
 				}	
 				
-				if (tAttr.filesize <= uCsize ) break;
+				if (tAttr.filesize <= (libssh2_uint64_t)uCsize ) break;
 			
 				if ((uLastSize = libssh2_sftp_read(pFtpFileHandle, buf, sizeof(buf))) == -1)
 				{
@@ -1055,9 +1129,10 @@ bool	SFtpReader::Paste(Selection& tSelection)
 	string			sCurName, sTargetPathTmp, sTargetPathTmp2;
 	string			sSourceName, sTargetName;
 	vector<File*>	vFiles;
-	struct stat 	src_stat, tar_stat, dir_stat;
+	struct stat 	src_stat;
 
-	char	buf[8192];
+	int		nBufSize = g_tCfg.GetValueNum("SSH", "DefBufSize", 65536);
+	char	buf[nBufSize];
 
 	ullong	uFileSize = tSelection.CalcSize();
 	uint	uSize = tSelection.GetSize();
@@ -1081,7 +1156,7 @@ bool	SFtpReader::Paste(Selection& tSelection)
 	tProgress.Start();
 
 	// 파일 디렉토리 먼저 생성 복사
-	for (int n=0; n<vFiles.size(); n++)
+	for (int n=0; n<(int)vFiles.size(); n++)
 	{
 		File*	pFile = vFiles[n];
 		
@@ -1112,7 +1187,7 @@ bool	SFtpReader::Paste(Selection& tSelection)
 		}
 	}
 
-	for (int n=0; n<vFiles.size(); n++)
+	for (int n=0; n<(int)vFiles.size(); n++)
 	{
 		File*	pFile = vFiles[n];
 		
@@ -1186,32 +1261,40 @@ askagain_sftp_paste:
 						
 					case 2: // rename 
 					{
-						struct stat statbuf;
-						string sRename = pFile->sName;
-						
-						while(1)
+						if ( !pFile->bDir )
+						{
+							string sRename = pFile->sName;
+							
+							while(1)
+							{
+								tProgress.End();
+								if (InputBox(	_("Rename"), sRename) < 0) goto askagain_sftp_paste;
+								tProgress.Start();
+	
+								sTargetName = sTargetPathTmp2 + sRename;
+								
+								if ( libssh2_sftp_rename_ex( 	(LIBSSH2_SFTP*)_pSessionSFtp, 
+									(char*)pFile->sFullName.c_str(), 
+									pFile->sFullName.size(),
+									(char*)sTargetName.c_str(),
+									sTargetName.size(), 
+									0644) == -1)
+								{							
+									tProgress.End();
+									MsgBox(	_("Error"), _("File exists"));
+									tProgress.Start();
+									continue;
+								}
+								tProgress.End();
+							}
+						}
+						else
 						{
 							tProgress.End();
-							if (InputBox(	_("Rename"), sRename) < 0) goto askagain_sftp_paste;
+							MsgBox(	_("Error"), _("Directory can't rename."));
 							tProgress.Start();
-
-							sTargetName = sTargetPathTmp2 + sRename;
-							
-							if ( libssh2_sftp_rename_ex( 	(LIBSSH2_SFTP*)_pSessionSFtp, 
-								(char*)pFile->sFullName.c_str(), 
-								pFile->sFullName.size(),
-								(char*)sTargetName.c_str(),
-								sTargetName.size(), 
-								0644) == -1)
-							{							
-								tProgress.End();
-								MsgBox(	_("Error"), _("File exists"));
-								tProgress.Start();
-								continue;
-							}
-							tProgress.End();
-							break;
 						}
+						break;
 					}
 					
 					case 3: // overwriteall
@@ -1324,7 +1407,7 @@ halt_sftp_paste:
 	return true;
 }
 
-bool SFtpReader::Remove(MLS::Selection& tSelection, bool bMsgShow)
+bool SFtpReader::Remove(MLS::Selection& tSelection, bool bMsgShow, bool bIgnore)
 {
 	CommonProgress tProgress(_("sftp delete file"), "", true);
 	if (bMsgShow)
@@ -1346,7 +1429,7 @@ bool SFtpReader::Remove(MLS::Selection& tSelection, bool bMsgShow)
 	vector<File*>	vFile, vDirs;
 	
 	// 파일 이동
-	for (int t=0; t< vFiles.size(); t++)
+	for (int t=0; t< (int)vFiles.size(); t++)
 	{
 		File*	pFile = vFiles[t];
 		// 파일 이름이 없을경우 continue
@@ -1375,7 +1458,7 @@ bool SFtpReader::Remove(MLS::Selection& tSelection, bool bMsgShow)
 	begin = vDirs.begin();	end = vDirs.end();
 	sort(begin, end, sort_dir_adaptor<sort_fullname_length, sort_fullname_length>());
 
-	for (int n=0; n < vFile.size(); n++)
+	for (int n=0; n < (int)vFile.size(); n++)
 	{
 		File*	pFile = vFile[n];
 		sTargetName = pFile->sFullName;
@@ -1422,7 +1505,7 @@ bool SFtpReader::Remove(MLS::Selection& tSelection, bool bMsgShow)
 	}
 
 	// 디렉토리는 나중에 삭제
-	for (int n=0; n < vDirs.size(); n++)
+	for (int n=0; n < (int)vDirs.size(); n++)
 	{
 		File*	pFile = vDirs[n];
 		sTargetName = pFile->sFullName;
@@ -1476,9 +1559,11 @@ bool  SFtpReader::View(const File* pFileOriginal, File* pFileChange)
 { 
 	string	sSourceName, sTargetName;
 	LIBSSH2_SFTP_ATTRIBUTES 	tAttr;
-	char	buf[8192];
 
-	// 파일 이름이 없을경우 continue
+	int		nBufSize = g_tCfg.GetValueNum("SSH", "DefBufSize", 65536);
+	char	buf[nBufSize];
+	 
+	// 파일 이름이 없을경우 continue 
 	if (!pFileOriginal) return false;
 
 	// 소스 이름과 타겟 이름 정하기	
@@ -1547,7 +1632,7 @@ bool  SFtpReader::View(const File* pFileOriginal, File* pFileChange)
 				tProgress.Start();
 			}
 			
-			if (tAttr.filesize <= uCsize ) break;
+			if (tAttr.filesize <= (libssh2_uint64_t)uCsize ) break;
 			
 			uLastSize = libssh2_sftp_read(pFtpFileHandle, buf, sizeof(buf));
 			fwrite(buf, 1, uLastSize, out);
@@ -1574,7 +1659,6 @@ bool  SFtpReader::View(const File* pFileOriginal, File* pFileChange)
 	fclose(out);
 	libssh2_sftp_close_handle(pFtpFileHandle);
 
-halt_sftp_view:
 	tProgress.End();
 	*pFileChange = *pFileOriginal;
 	pFileChange->sTmp2 = pFileOriginal->sFullName;
@@ -1604,7 +1688,7 @@ void	SFtpReader::EncodeChk(vector<File*>& tFileList, bool bEncChk)
 	bool		bChgEncode = false;
 	if ( tFileList.size() == 0 ) bChgEncode = true;
 
-	for ( int n = 0; n < tFileList.size(); n++ )
+	for ( int n = 0; n < (int)tFileList.size(); n++ )
 	{
 		isKorCode(tFileList[n]->sFullName,	&eEncode);
 		if ( eEncode != US )
