@@ -1,4 +1,4 @@
-/* Copyright (c) 2004-2005, Sara Golemon <sarag@libssh2.org>
+/* Copyright (c) 2004-2006, Sara Golemon <sarag@libssh2.org>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms,
@@ -39,28 +39,27 @@
 #define LIBSSH2_PRIV_H 1
 
 #define LIBSSH2_LIBRARY
-
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
 //#include "libssh2_config.h"
-
+#include "config.h"
 #include "libssh2.h"
 
 #ifndef WIN32
 #include <sys/socket.h>
 #endif
 #include <openssl/evp.h>
-
-/***************************/
-// cygwin compile bugfix.
-#include <openssl/md5.h>
+#ifndef OPENSSL_NO_SHA
 #include <openssl/sha.h>
-/***************************/
+#endif
+#ifndef OPENSSL_NO_MD5
+#include <openssl/md5.h>
+#endif
+
+#ifdef __hpux
+# define inline 
+#endif
 
 #define LIBSSH2_ALLOC(session, count)								session->alloc((count), &(session)->abstract)
-#define LIBSSH2_REALLOC(session, ptr, count)						session->realloc((ptr), (count), &(session)->abstract)
+#define LIBSSH2_REALLOC(session, ptr, count)						((ptr) ? session->realloc((ptr), (count), &(session)->abstract) : session->alloc((count), &(session)->abstract))
 #define LIBSSH2_FREE(session, ptr)									session->free((ptr), &(session)->abstract)
 
 #define LIBSSH2_IGNORE(session, data, datalen)						session->ssh_msg_ignore((session), (data), (datalen), &(session)->abstract)
@@ -344,6 +343,7 @@ struct _LIBSSH2_MAC_METHOD {
 #define LIBSSH2_DBG_SCP							5
 #define LIBSSH2_DBG_SFTP						6
 #define LIBSSH2_DBG_ERROR						7
+#define LIBSSH2_DBG_PUBLICKEY					8
 
 void _libssh2_debug(LIBSSH2_SESSION *session, int context, const char *format, ...);
 
