@@ -174,11 +174,13 @@ void CmdMcdImp::Menu()
 	McdMenu		tMcdMenu;
 	vector<string>	vDisableList;
 
-	if (_pPanel->GetReader()->GetReaderName() == "file")
+	const string&	sReaderName = _pMcd->GetReader()->GetReaderName();
+
+	if (sReaderName == "file")
 	{
 		vDisableList.push_back("Cmd_RemoteClose");
 	}
-	else if (_pPanel->GetReader()->GetReaderName() == "ftp")
+	else if (sReaderName == "ftp" || sReaderName == "sftp")
 	{
 		vDisableList.push_back("Cmd_RemoteConnect");
 	}
@@ -786,4 +788,3 @@ void	CmdMcdImp::McdLoad()
 	_pMcd->AddDirectory(_pPanel->GetReader()->GetPath());
 	_pMcd->SetCur(_pPanel->GetReader()->GetPath());
 }
-
