@@ -6,6 +6,8 @@
 #include "archive.h"
 #include "ncurses_qcd.h"
 #include "dialogbox.h"
+#include "dialog_remoteconnprops.h"
+#include "remotecfgload.h"
 
 #include <fcntl.h>
 
@@ -331,6 +333,8 @@ void CmdPanelImp::Key_Enter()
 	else
 	{
 		_pPanel->Key_Enter();
+		if ( g_tCfg.GetBool("Default", "AlwaysCleanRefresh") )
+			Refresh();
 	}
 }
 
@@ -594,10 +598,12 @@ void CmdPanelImp::Menu()
 	else if (sReaderName == "ftp" || sReaderName == "sftp")
 	{
 		vDisableList.push_back("Cmd_RemoteConnect");
+		vDisableList.push_back("Cmd_RemoteConnProps");
 	}
 	else
 	{
 		vDisableList.push_back("Cmd_RemoteConnect");
+		vDisableList.push_back("Cmd_RemoteConnProps");
 		vDisableList.push_back("Cmd_RemoteClose");
 	}
 
@@ -632,7 +638,7 @@ void CmdPanelImp::Quit()
 	// 마지막 mls 가 마지막으로 사용한 디렉토리를 저장한다.
 	if (_pPanel->GetReader()->GetReaderName() == "file")
 	{
-		FILE *fp= fopen((g_tCfg.GetValue("CfgHome") + "path").c_str(), "wb");
+		FILE *fp= fopen((g_tCfg.GetValue("Static", "CfgHome") + "path").c_str(), "wb");
 
 		if (fp)
 		{
@@ -1292,7 +1298,7 @@ void 	CmdPanelImp::NewFile()
 	_pEditor->SetViewTitle( sTitle );
 	_pEditor->SetEditor(nSize, bEditorBackup, bEditorLineNum);
 	_pEditor->New(sFilename);
-    
+
 	g_tMainFrame.SetActiveViewType(EDITOR);
 	_pEditor->_bFocus = true;
 		
@@ -1337,30 +1343,30 @@ void	CmdPanelImp::FileCompress(int nType)
 		return;
 	}
 
-    string	sTitle = _("Input name of the compressed file. [filename]");
-    string	sFileName;
+	string	sTitle = _("Input name of the compressed file. [filename]");
+	string	sFileName;
 
-    switch(nType)
-    {
-        case 0:
-            InputBox((sTitle + ".tar.gz").c_str(), sFileName);
-            if (sFileName == "") return;
-            sFileName = sFileName + ".tar.gz";
-            break;
-        case 1:
-            InputBox((sTitle + ".tar.bz2").c_str(), sFileName);
-            if (sFileName == "") return;
-            sFileName = sFileName + ".tar.bz2";
-            break;
-        case 2:
-            InputBox((sTitle + ".zip").c_str(), sFileName);
-            if (sFileName == "") return;
-            sFileName = sFileName + ".zip";
-            break;
-        default:
-            return;
-            break;
-    }
+	switch(nType)
+	{
+		case 0:
+			InputBox((sTitle + ".tar.gz").c_str(), sFileName);
+			if (sFileName == "") return;
+			sFileName = sFileName + ".tar.gz";
+			break;
+		case 1:
+			InputBox((sTitle + ".tar.bz2").c_str(), sFileName);
+			if (sFileName == "") return;
+			sFileName = sFileName + ".tar.bz2";
+			break;
+		case 2:
+			InputBox((sTitle + ".zip").c_str(), sFileName);
+			if (sFileName == "") return;
+			sFileName = sFileName + ".zip";
+			break;
+		default:
+			return;
+			break;
+	}
 
 	sFileName = _pPanel->GetReader()->GetPath() + sFileName;
 
@@ -1481,7 +1487,7 @@ void	CmdPanelImp::Extract()
 		if (nFileinfo == ERROR)
 		{
 			q.push_back(_("Cancel"));
-			g_Log.Write("Extract()()()()() !!!");
+			g_Log.Write("Extract() !!!");
 			int nSelect = SelectBox(sMsg.c_str(), q, 0);
 			if (nSelect == -1) return;
 			
@@ -1801,3 +1807,208 @@ void	CmdPanelImp::Chmod()
 	}
 }
 
+void	CmdPanelImp::RemoteConnProps()
+{
+	if (g_tMainFrame.GetActiveViewType() != PANEL) return;
+
+	if (_pPanel->GetReader()->GetReaderName() != "file" )
+	{
+		MsgBox(_("Error"), _("current remote connected."));
+		return; 
+	}
+
+	RemoteCfgLoad				tRemoteCfg;
+
+	string sPath = g_tCfg.GetValue("Default", "RemoteConnCfgFile", "remoteconn.cfg");
+	sPath = g_tCfg.GetValue("Static", "CfgHome") + sPath;
+	
+	tRemoteCfg.Load( sPath );
+
+	if ( COLS < 60 )
+	{
+		MsgBox(_("Error"), _("Terminal size is too small."));
+		return;
+	}
+
+	bool bExit = false;
+	bool bModify = false;
+
+	int	nNum = 0;
+
+	do
+	{
+		vector<string>				vData;
+		String						sStr;
+
+		int nButtonNum = 1;
+	
+		for (int n = 0; n < tRemoteCfg._vConnInfo.size(); n++)
+			vData.push_back(tRemoteCfg._vConnInfo[n].sName.c_str());
+		
+		if (tRemoteCfg._vConnInfo.size() > 0)
+		{
+			if (nNum > tRemoteCfg._vConnInfo.size()) 
+				nNum = tRemoteCfg._vConnInfo.size();
+
+			Dialog_RemoteConnProps		tProps(_("Remote Connect Properties"), nNum);
+	
+			tProps.SetSelData( vData );
+			tProps.Size(20, 60);
+			tProps.Move(MIDDLE, MIDDLE);
+			
+			tProps.Do();
+			tProps.Close();
+
+			nButtonNum = tProps.GetButtonNum();
+			nNum = tProps.GetListCur();
+			Refresh();
+		}
+		
+		switch( nButtonNum )
+		{
+			case 1: // Insert
+			{
+				bool	bContinue = false;
+				do
+				{
+					bContinue = false;
+
+					Dialog_RemoteConnInsert		tConnInsert(_("Remote Connect Insert"));
+					tConnInsert.Size(18, 60);
+					tConnInsert.Move(MIDDLE, MIDDLE);
+					tConnInsert.Do();
+					
+					if (tConnInsert.GetOk() == true)
+					{
+						RemoteConnEntry		tEntry;
+						tConnInsert.GetRemoteConnEntry(tEntry);
+
+						for (int n = 0; n < tRemoteCfg._vConnInfo.size(); n++)
+						{
+							if (tRemoteCfg._vConnInfo[n].sName == tEntry.sName)
+							{
+								MsgBox(_("Error"), _("Connection Name Overlapping."));
+								bContinue = true;
+								break;
+							}
+						}
+						
+						if ( !bContinue )
+						{
+							tRemoteCfg._vConnInfo.push_back(tEntry);
+							nNum = tRemoteCfg._vConnInfo.size() - 1;
+						}
+						bModify = true;
+					}
+					else if (tRemoteCfg._vConnInfo.size() == 0)
+					{
+						bExit = true;
+					}
+				}
+				while( bContinue );
+				break;
+			}
+	
+			case 2: // Modify
+			{
+				bool	bContinue = false;
+				do
+				{
+					bContinue = false;
+
+					Dialog_RemoteConnInsert		tConnModify(_("Remote Connect Modify"));
+					tConnModify.Size(18, 60);
+					tConnModify.Move(MIDDLE, MIDDLE);
+					tConnModify.SetRemoteConnEntry( tRemoteCfg._vConnInfo[nNum] );
+					tConnModify.Do();
+					if (tConnModify.GetOk() == true)
+					{
+						RemoteConnEntry		tEntry;
+						tConnModify.GetRemoteConnEntry(tEntry);
+
+						for (int n = 0; n < tRemoteCfg._vConnInfo.size(); n++)
+						{
+							if (tRemoteCfg._vConnInfo[n].sName == tEntry.sName 
+								&& tRemoteCfg._vConnInfo[nNum].sName != tEntry.sName )
+							{
+								MsgBox(_("Error"), _("Connection Name Overlapping."));
+								bContinue = true;
+								break;
+							}
+						}
+
+						if ( !bContinue )
+							tRemoteCfg._vConnInfo[nNum] = tEntry;
+						bModify = true;
+					}
+				}
+				while( bContinue );
+				break;
+			}
+	
+			case 3:	// Delete
+			{
+				String sMsg(_("Do you really remove connection infomation? - %s"), 
+							tRemoteCfg._vConnInfo[nNum].sName.c_str());
+				if (YNBox(_("Error"), sMsg.c_str(), false) == true)
+				{
+					tRemoteCfg._vConnInfo.erase(tRemoteCfg._vConnInfo.begin()+nNum);
+					bModify = true;
+				}
+				break;
+			}
+			
+			case 4:	// Close
+			{
+				bExit = true;
+				break;
+			}
+
+			case 0: // List
+			{
+				string sConnectionInfo = tRemoteCfg._vConnInfo[nNum].GetURLFormat(true);
+			
+				if (sConnectionInfo.size() > 6)
+				{
+					if (sConnectionInfo.substr(0, 6) == "ftp://")
+					{
+						sConnectionInfo = sConnectionInfo.substr(6);
+						_pPanel->PluginOpen(sConnectionInfo, "ftp");
+						if (_pPanel->GetReader()->GetConnected())
+						{
+							_pPanel->Read(tRemoteCfg._vConnInfo[nNum].sDirectory);
+							bExit = true;
+						}
+					}
+					else if (sConnectionInfo.substr(0, 7) == "sftp://")
+					{
+						sConnectionInfo = sConnectionInfo.substr(7);
+						_pPanel->PluginOpen(sConnectionInfo, "sftp");
+						if (_pPanel->GetReader()->GetConnected())
+						{
+							_pPanel->Read(tRemoteCfg._vConnInfo[nNum].sDirectory);
+							bExit = true;
+						}
+					}
+					else
+					{
+						MsgBox(_("Error"), _("input url invalid format."));
+					}
+				}
+			}
+		}
+		
+		Refresh();
+		g_tMainFrame.Refresh(false);
+	}
+	while( !bExit );
+
+	if ( bModify ) 
+		tRemoteCfg.Save( sPath );
+}
+
+void	CmdPanelImp::SyncDirectory()
+{
+	g_tMainFrame.SyncDirectory();
+}
+
