@@ -64,7 +64,8 @@ void	DrawTop::Draw()
 		}
 
 		setcol(tColorFunc, pWin);
-		string			sCmd = g_tKeyCfg.GetCommand( sStr.c_str(), _eViewType );
+		
+		string	sCmd = g_tKeyCfg.GetCommand( sStr.c_str(), _eViewType );
 		sCmd = g_tKeyCfg.GetHelp( sCmd, _eViewType );
 		if ( sCmd.size() > 0)
 			mvwprintw(pWin, y, x+sStr.size()+pos, "%s", _(sCmd.c_str()));
@@ -77,6 +78,7 @@ void	DrawTop::Draw()
 		mvwaddch(pWin, y, x+pos, VLINE);
 	}
 	wnoutrefresh(pWin);
+	//wrefresh(pWin);
 }
 
 
@@ -126,6 +128,7 @@ void	DrawPath::Draw()
 	
 	mvwprintw(pWin, y, x, "%s", sStr.c_str());
 	wnoutrefresh(pWin);
+	//wrefresh(pWin);
 }
 
 void	Hint::Draw()
@@ -207,6 +210,7 @@ void	StatusInfo::Draw()
 	//  FileManager Status
 	ColorEntry tColorStatA = g_tColorCfg.GetColorEntry("StatA");
 	ColorEntry tColorStat = g_tColorCfg.GetColorEntry("Stat");
+	ColorEntry tColorDir = g_tColorCfg.GetColorEntry("Dir");
 
 	setcol(tColorStatA, pWin);
 	wmove(pWin, y, x);
@@ -215,29 +219,27 @@ void	StatusInfo::Draw()
 	setcol(tColorStatA, pWin);
 	mvwprintw(pWin, y, x+0, "%5d ", _pPanel->_uFile);
 	mvwprintw(pWin, y, x+10, "%5d ", _pPanel->_uDir);
-	mvwprintw(pWin, y, x+23, "%14.14s ", toregular(_pPanel->_uDirSize).c_str());
+	mvwprintw(pWin, y, x+24, "%15.15s ", toregular(_pPanel->_uDirSize).c_str());
 
 	if (_pPanel->_uSelNum)
 	{
-		mvwprintw(pWin, y, x+42, "%5d", _pPanel->_uSelNum);
-		if (_pPanel->_uSelSize >= 1000000000)
-			mvwprintw(pWin, y, x+58, " %10.3f G", (float)_pPanel->_uSelSize/1073741824);
-		else
-			mvwprintw(pWin, y, x+58, " %11.11s ", toregular(_pPanel->_uSelSize).c_str());
+		mvwprintw(pWin, y, x+43, "%5d", _pPanel->_uSelNum);
+		mvwprintw(pWin, y, x+59, " %15.15s ", toregular(_pPanel->_uSelSize).c_str());
 	}
 
 	setcol(tColorStat, pWin);
 	mvwprintw(pWin, y, x+6,	_("File"));
 	mvwprintw(pWin, y, x+16, 	_("Dir"));
-	mvwprintw(pWin, y, x+38, 	_("Byte"));
+	mvwprintw(pWin, y, x+39, 	_("Byte"));
 
 	if (_pPanel->_uSelNum)
 	{
-		mvwprintw(pWin, y, x+47, _(" Selected ("));
-		mvwprintw(pWin, y, x+71, _("Bytes)       "));
+		mvwprintw(pWin, y, x+48, _(" Selected ("));
+		mvwprintw(pWin, y, x+72, _("Bytes)       "));
 	}
 	
 	wnoutrefresh(pWin);
+	//wrefresh(pWin);
 }
 
 void	DirInfo::Draw()
@@ -265,7 +267,7 @@ void	DirInfo::Draw()
 		vGubun.push_back( sView.size() ); sView.Append(" ");
 	}
 	if ( pFile->uSize )
-		sView.Append(" %10.0d ", pFile->uSize);
+		sView.Append(" %10s ", toregular(pFile->uSize).c_str());
 	else
 		sView.Append("          0 ");
 	vGubun.push_back( sView.size() ); 
@@ -273,7 +275,13 @@ void	DirInfo::Draw()
 	sView.Append(" %s %s ", pFile->sDate.c_str(), pFile->sTime.c_str());
 	vGubun.push_back( sView.size() ); 
 	sView.Append(" ");
-	sView.Append(" %s", pFile->sName.substr(0, width-38).c_str());
+
+	string	sName = pFile->sName;
+	
+	if ( pFile->bLink )
+		sName = sName + " -> " + pFile->sLinkName;
+
+	sView.Append(" %s", sName.substr(0, width-38).c_str());
 
 	mvwprintw(pWin, y, x, "%s", sView.c_str());
 	
@@ -284,6 +292,7 @@ void	DirInfo::Draw()
 	}
 
 	wnoutrefresh(pWin);
+	//wrefresh(pWin);
 }
 
 deque<wstring> g_tCmdHistory;
@@ -451,7 +460,7 @@ int 	ShellCmd::DataInput(KeyInfo& tKeyInfoBef)
 				if (_vCom_entry.empty()) break;
 	
 				wstring rf;
-				if (g_tCfg.GetBool("TabFileRotate"))
+				if (g_tCfg.GetBool("Default", "TabFileRotate", false))
 					rf = strtowstr(addslash(_vCom_entry[_nTabIndex % _vCom_entry.size()]));
 				else
 					rf = strtowstr(addslash(Com_entry(_vCom_entry, _nStart)));
@@ -607,6 +616,7 @@ void	ShellCmd::Draw()
 	int nViewcur = wstrlen(_sWStr.substr(_nFirst, _nCur-_nFirst));
 	wmove(pWin, y, x+nViewcur+scrstrlen(sPrompt));
 	wnoutrefresh(pWin);
+	//wrefresh(pWin);
 	curs_set(1);
 }
 
