@@ -20,11 +20,11 @@ Qcd::~Qcd()
 
 void Qcd::UpdateConfig()
 {
-	_vItem.resize(10);
-
+	_vItem.clear();
+	
 	for (int t=0; t<10; t++)
-		_vItem[t] = _Config.GetValue("QCD", "QcdF" + itoa(t+1));
-
+		_vItem.push_back(_Config.GetValue("QCD", "QcdF" + itoa(t+1)));
+	
 	SetSelData( _vItem, true );
 }
 
@@ -39,7 +39,7 @@ void Qcd::Execute(KeyInfo& tKeyInfo)
 	switch((int)tKeyInfo)
 	{
 		case KEY_ENTER:
-			if ( !_vItem[_nCur].empty() ) 
+			if ( !_vItem[_nCur].empty() )
 			{
 				_bExit = true;
 				break;
@@ -48,8 +48,11 @@ void Qcd::Execute(KeyInfo& tKeyInfo)
 			g_tMainFrame.SetMcdExeMode(EXECUTE_QCD, itoa(_nCur+1));
 			_bExit = true;
 			return;
+		case KEY_BS:
 		case KEY_DC:
-			_vItem[_nCur].erase();
+			_vItem[_nCur] = "";
+			SaveConfig();
+			UpdateConfig();
 			break;
 	}
 
